@@ -9,7 +9,7 @@
 #
 package Redis;
 {
-  $Redis::VERSION = '1.975';
+  $Redis::VERSION = '1.976';
 }
 
 # ABSTRACT: Perl binding for Redis database
@@ -28,7 +28,6 @@ use Fcntl qw( O_NONBLOCK F_SETFL );
 use Errno ();
 use Data::Dumper;
 use Carp;
-use Encode;
 use Try::Tiny;
 use Scalar::Util ();
 
@@ -698,8 +697,8 @@ sub __send_command {
   my $n_elems = scalar(@_) + scalar(@cmd);
   my $buf     = "\*$n_elems\r\n";
   for my $bin (@cmd, @_) {
-    # force to consider inputs as bytes strings.
-    Encode::_utf8_off($bin);
+    utf8::downgrade($bin, 1)
+      or croak "command sent is not an octet sequence in the native encoding (Latin-1). Consider using debug mode to see the command itself.";
     $buf .= defined($bin) ? '$' . length($bin) . "\r\n$bin\r\n" : "\$-1\r\n";
   }
 
@@ -904,7 +903,7 @@ Redis - Perl binding for Redis database
 
 =head1 VERSION
 
-version 1.975
+version 1.976
 
 =head1 SYNOPSIS
 
@@ -1064,11 +1063,10 @@ useful for Redis transactions; see L</exec>.
 =head1 ENCODING
 
 There is no encoding feature anymore, it has been deprecated and finally
-removed. This module consider that any data sent to the Redis server is a raw
-octets string, even if it has utf8 flag set. And it doesn't do anything when
-getting data from the Redis server.
+removed. This module consider that any data sent to the Redis server is a binary data.
+And it doesn't do anything when getting data from the Redis server.
 
-So, do you pre-encoding or post-decoding operation yourself if needed !
+So, if you are working with character strings, you should pre-encode or post-decode it if needed !
 
 =head1 METHODS
 
